package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcMaterialGive;

/**
 * cmc耗材发放Mapper接口
 * 
 * @author cmc
 * @date 2024-07-31
 */
public interface CmcMaterialGiveMapper 
{
    /**
     * 查询cmc耗材发放
     * 
     * @param giveId cmc耗材发放主键
     * @return cmc耗材发放
     */
    public CmcMaterialGive selectCmcMaterialGiveByGiveId(Integer giveId);

    /**
     * 查询cmc耗材发放列表
     * 
     * @param cmcMaterialGive cmc耗材发放
     * @return cmc耗材发放集合
     */
    public List<CmcMaterialGive> selectCmcMaterialGiveList(CmcMaterialGive cmcMaterialGive);

    /**
     * 新增cmc耗材发放
     * 
     * @param cmcMaterialGive cmc耗材发放
     * @return 结果
     */
    public int insertCmcMaterialGive(CmcMaterialGive cmcMaterialGive);

    /**
     * 修改cmc耗材发放
     * 
     * @param cmcMaterialGive cmc耗材发放
     * @return 结果
     */
    public int updateCmcMaterialGive(CmcMaterialGive cmcMaterialGive);

    /**
     * 删除cmc耗材发放
     * 
     * @param giveId cmc耗材发放主键
     * @return 结果
     */
    public int deleteCmcMaterialGiveByGiveId(Integer giveId);

    /**
     * 批量删除cmc耗材发放
     * 
     * @param giveIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcMaterialGiveByGiveIds(Integer[] giveIds);
}
